@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import re
 from typing import Any, Iterator, cast
 
 from attr import define, field
@@ -24,6 +25,9 @@ from pyoverkiz.types import DATA_TYPE_TO_PYTHON, StateType
 
 # pylint: disable=unused-argument, too-many-instance-attributes, too-many-locals
 
+# <protocol>://<gatewayId>/<deviceAddress>[#<subsystemId>]
+DEVICE_URL_RE = r"(?P<protocol>.+)://(?P<gatewayId>\d{4}-\d{4}-\d{4})/(?P<deviceAddress>[^#]+)(#(?P<subsystemId>\d+))?"
+
 
 @define(init=False, kw_only=True)
 class Setup:
@@ -140,6 +144,10 @@ class Device:
     enabled: bool
     label: str = field(repr=obfuscate_string)
     device_url: str = field(repr=obfuscate_id)
+    gateway_id: str = field(repr=obfuscate_id)
+    device_address: str = field(repr=obfuscate_id)
+    subsystem_id: int | None = None
+    is_sub_device: bool = False
     controllable_name: str
     definition: Definition
     data_properties: list[dict[str, Any]] | None = None
@@ -181,7 +189,21 @@ class Device:
         self.data_properties = data_properties
         self.type = ProductType(type)
         self.place_oid = place_oid
-        self.protocol = Protocol(self.device_url.split(":")[0])
+
+        # Split <protocol>://<gatewayId>/<deviceAddress>[#<subsystemId>] into multiple variables
+        match = re.search(DEVICE_URL_RE, device_url)
+
+        self.subsystem_id = None
+        self.is_sub_device = False
+
+        if match:
+            self.protocol = Protocol(match.group("protocol"))
+            self.gateway_id = match.group("gatewayId")
+            self.device_address = match.group("deviceAddress")
+
+            if match.group("subsystemId"):
+                self.subsystem_id = int(match.group("subsystemId"))
+                self.is_sub_device = self.subsystem_id > 1
 
         if ui_class:
             self.ui_class = UIClass(ui_class)
